pub struct AuthGroupsExtended {
pub groups: Option<Vec<AuthGroupExtended>>,
pub resume: Option<String>,
}Fields
groups: Option<Vec<AuthGroupExtended>>resume: Option<String>Continue returning results from previous call using this token (token should come from the previous call, resume cannot be used with other options).