pub struct AuthUsersExtended {
pub users: Option<Vec<MappingUsersLookupMappingItemUser>>,
pub resume: Option<String>,
}Fields
users: Option<Vec<MappingUsersLookupMappingItemUser>>resume: Option<String>Continue returning results from previous call using this token (token should come from the previous call, resume cannot be used with other options).