pub struct ChangelistLins {
pub atime: Option<ChangelistLinsCtime>,
pub ctime: Option<ChangelistLinsCtime>,
pub id: String,
pub mtime: Option<ChangelistLinsCtime>,
pub path: String,
pub size: i32,
pub _type: String,
}Fields
atime: Option<ChangelistLinsCtime>ctime: Option<ChangelistLinsCtime>id: StringThe LIN number of the file associated with the entry.
mtime: Option<ChangelistLinsCtime>path: StringThe path to the file associated with the entry.
size: i32The size of the file associated with the entry.
_type: StringType of file.