CloudAccount

Struct CloudAccount 

pub struct CloudAccount {
    pub account_id: Option<String>,
    pub account_username: Option<String>,
    pub birth_cluster_id: Option<String>,
    pub enabled: Option<bool>,
    pub key: Option<String>,
    pub name: Option<String>,
    pub proxy: Option<String>,
    pub skip_account_check: Option<bool>,
    pub skip_ssl_validation: Option<bool>,
    pub storage_region: Option<String>,
    pub telemetry_bucket: Option<String>,
    pub uri: Option<String>,
}

Fields

account_id: Option<String>

(S3 only) The user id of the S3 account

account_username: Option<String>

The username required to authenticate against the cloud service

birth_cluster_id: Option<String>

The guid of the cluster where this account was created

enabled: Option<bool>

Whether this account is explicitly enabled or disabled by a user

key: Option<String>

A valid authentication key for connecting to the cloud

name: Option<String>

A unique name for this account

proxy: Option<String>

The id or name of a proxy to be used by this account

skip_account_check: Option<bool>

(Not recommended) Indicates whether to skip validation that the cloud account is still accessible

skip_ssl_validation: Option<bool>

Indicates whether to skip SSL certificate validation when connecting to the cloud

storage_region: Option<String>

(S3 only) An appropriate region for the S3 account. For example, faster access times may be gained by referencing a nearby region

telemetry_bucket: Option<String>

(S3 only) The name of the bucket into which generated metrics reports are placed by the cloud service provider

uri: Option<String>

A valid URI pointing to the location of the cloud storage