pub struct CloudJob {
pub all: Option<bool>,
pub state: Option<String>,
}Fields
all: Option<bool>Whether to apply to the given operation type or to all jobs of the given operation type
state: Option<String>The desired state of the job or operation