pub struct CloudProxies {
pub proxies: Option<Vec<CloudProxyExtended>>,
pub resume: Option<String>,
}Fields
proxies: Option<Vec<CloudProxyExtended>>resume: Option<String>Continue returning results from previous call using this token (token should come from the previous call, resume cannot be used with other options).