pub struct CloudProxiesExtended {
pub proxies: Option<Vec<CloudProxyExtended>>,
pub resume: Option<String>,
pub total: Option<i32>,
}Fields
proxies: Option<Vec<CloudProxyExtended>>resume: Option<String>Continue returning results from previous call using this token (token should come from the previous call, resume cannot be used with other options).
total: Option<i32>Total number of items available.