pub struct CloudProxy {
pub host: Option<String>,
pub name: Option<String>,
pub password: Option<String>,
pub port: Option<i32>,
pub _type: Option<String>,
pub username: Option<String>,
}Fields
host: Option<String>A host name or network address for connecting to this proxy
name: Option<String>A unique friendly name for this proxy configuration
password: Option<String>The password to connect to this proxy if required (write-only)
port: Option<i32>The port used to connect to this proxy
_type: Option<String>The type of connection used to connect to this proxy
username: Option<String>The username to connect to this proxy if required