pub struct CloudProxyCreateParams {
pub host: String,
pub name: String,
pub password: Option<String>,
pub port: i32,
pub _type: String,
pub username: Option<String>,
}Fields
host: StringA host name or network address for connecting to this proxy
name: StringA unique friendly name for this proxy configuration
password: Option<String>The password to connect to this proxy if required (write-only)
port: i32The port used to connect to this proxy
_type: StringThe type of connection used to connect to this proxy
username: Option<String>The username to connect to this proxy if required