pub struct ClusterConfigDevice {
pub devid: i32,
pub guid: String,
pub is_up: bool,
pub lnn: i32,
}Fields
devid: i32Device ID.
guid: StringDevice GUID.
is_up: boolIf true, this node is online and communicating with the local node and every other node with the is_up property normally. If false, this node is not currently communicating with the local node or other nodes with the is_up property. It may be shut down, rebooting, disconnected from the backend network, or connected only to other nodes.
lnn: i32Device logical node number.