pub struct ClusterNodeDriveDConfig {
pub alert: Option<NodeDriveconfigNodeAlert>,
pub allow: Option<NodeDriveconfigNodeAllow>,
pub automatic_replacement_recognition: Option<NodeDriveconfigNodeAutomaticReplacementRecognition>,
pub log: Option<NodeDriveconfigNodeLog>,
pub reboot: Option<NodeDriveconfigNodeReboot>,
pub spin_wait: Option<NodeDriveconfigNodeSpinWait>,
pub stall: Option<NodeDriveconfigNodeStall>,
}Fields
alert: Option<NodeDriveconfigNodeAlert>Configuration setting for drive alerts.
allow: Option<NodeDriveconfigNodeAllow>Configuration settings for drive formatting.
automatic_replacement_recognition: Option<NodeDriveconfigNodeAutomaticReplacementRecognition>Configuration settings for automatic replacement recognition (ARR).
log: Option<NodeDriveconfigNodeLog>Configuration settings for drive statistics logs.
reboot: Option<NodeDriveconfigNodeReboot>Configuration settings for a node reboot due to a drive error.
spin_wait: Option<NodeDriveconfigNodeSpinWait>Configuration settings for sleeping the drive daemon before node is rescanned.
stall: Option<NodeDriveconfigNodeStall>Configuration settings to evaluate a drive stall.