pub struct EventEventgroupDefinitionsExtended {
pub eventgroup_definitions: Option<Vec<EventEventgroupDefinitionsEventgroupDefinition>>,
pub resume: Option<String>,
pub total: Option<i32>,
}Fields
eventgroup_definitions: Option<Vec<EventEventgroupDefinitionsEventgroupDefinition>>resume: Option<String>Continue returning results from previous call using this token (token should come from the previous call, resume cannot be used with other options).
total: Option<i32>Total number of items available.