pub struct EventEventlistsExtended {
pub eventlists: Option<Vec<EventEventlist>>,
pub resume: Option<String>,
pub total: Option<i32>,
}Fields
eventlists: Option<Vec<EventEventlist>>resume: Option<String>Continue returning results from previous call using this token (token should come from the previous call, resume cannot be used with other options).
total: Option<i32>Total number of items available.