JobJobCreateParams

Struct JobJobCreateParams 

pub struct JobJobCreateParams {
    pub allow_dup: Option<bool>,
    pub avscan_params: Option<JobJobAvscanParams>,
    pub changelistcreate_params: Option<JobJobChangelistcreateParams>,
    pub domainmark_params: Option<JobJobDomainmarkParams>,
    pub paths: Option<Vec<String>>,
    pub policy: Option<String>,
    pub prepair_params: Option<JobJobPrepairParams>,
    pub priority: Option<i32>,
    pub smartpoolstree_params: Option<JobJobSmartpoolstreeParams>,
    pub snaprevert_params: Option<JobJobSnaprevertParams>,
    pub _type: String,
}

Fields

allow_dup: Option<bool>

Whether or not to queue the job if one of the same type is already running or queued.

avscan_params: Option<JobJobAvscanParams>
changelistcreate_params: Option<JobJobChangelistcreateParams>
domainmark_params: Option<JobJobDomainmarkParams>
paths: Option<Vec<String>>

For jobs which take paths, the IFS paths to pass to the job.

policy: Option<String>

Impact policy of this job instance.

prepair_params: Option<JobJobPrepairParams>
priority: Option<i32>

Priority of this job instance; lower numbers preempt higher numbers.

smartpoolstree_params: Option<JobJobSmartpoolstreeParams>
snaprevert_params: Option<JobJobSnaprevertParams>
_type: String

Job type to queue.