pub struct LicenseLicense {
pub days_since_expiry: Option<i32>,
pub days_to_expiry: Option<i32>,
pub expiration: Option<String>,
pub expired_alert: bool,
pub expiring_alert: bool,
pub id: String,
pub name: String,
pub status: String,
pub tiers: Vec<LicenseLicenseTier>,
}Fields
days_since_expiry: Option<i32>Number of days since a license expired.
days_to_expiry: Option<i32>Number of days before a license expires.
expiration: Option<String>Date of license expiry. Format is YYYY-MM-DD. It is not included if there is no expiration. Feature is considered expired at end of this day. The cluster time is used to determine expiry.
expired_alert: boolTrue when we are generating an alert that this feature has expired.
expiring_alert: boolTrue when we are generating an alert that this feature is expiring.
id: StringName of the licensed feature.
name: StringName of the licensed feature.
status: StringCurrent status of the license.
tiers: Vec<LicenseLicenseTier>Tiered License details.