pub struct MappingUsersRulesRuleOptionsExtended {
pub _break: Option<bool>,
pub default_user: Option<MappingUsersRulesRuleOptionsDefaultUser>,
pub group: Option<bool>,
pub groups: Option<bool>,
pub user: Option<bool>,
}Fields
_break: Option<bool>If true, and the rule was applied successfully, stop processing further.
default_user: Option<MappingUsersRulesRuleOptionsDefaultUser>group: Option<bool>If true, the primary GID and primary group SID should be copied to the existing credential.
groups: Option<bool>If true, all additional identifiers should be copied to the existing credential.
user: Option<bool>If true, the primary UID and primary user SID should be copied to the existing credential.