pub struct NetworkDnscacheSettings {Show 13 fields
pub cache_entry_limit: i32,
pub cluster_timeout: i32,
pub dns_timeout: i32,
pub eager_refresh: i32,
pub testping_delta: i32,
pub ttl_max_noerror: i32,
pub ttl_max_nxdomain: i32,
pub ttl_max_other: i32,
pub ttl_max_servfail: i32,
pub ttl_min_noerror: i32,
pub ttl_min_nxdomain: i32,
pub ttl_min_other: i32,
pub ttl_min_servfail: i32,
}Fields
cache_entry_limit: i32DNS cache entry limit
cluster_timeout: i32Timeout value for calls made to other nodes in the cluster
dns_timeout: i32Timeout value for calls made to the dns resolvers
eager_refresh: i32Lead time to refresh cache entries nearing expiration
testping_delta: i32Deltas for checking cbind cluster health
ttl_max_noerror: i32Upper bound on ttl for cache hits
ttl_max_nxdomain: i32Upper bound on ttl for nxdomain
ttl_max_other: i32Upper bound on ttl for non-nxdomain failures
ttl_max_servfail: i32Upper bound on ttl for server failures
ttl_min_noerror: i32Lower bound on ttl for cache hits
ttl_min_nxdomain: i32Lower bound on ttl for nxdomain
ttl_min_other: i32Lower bound on ttl for non-nxdomain failures
ttl_min_servfail: i32Lower bound on ttl for server failures