pub struct NodeDrivesPurposelist {
pub errors: Option<Vec<NodeDrivesPurposelistError>>,
pub nodes: Option<Vec<NodeDrivesPurposelistNode>>,
pub total: Option<i32>,
}Fields
errors: Option<Vec<NodeDrivesPurposelistError>>A list of errors encountered by the individual nodes involved in this request, or an empty list if there were no errors.
nodes: Option<Vec<NodeDrivesPurposelistNode>>The responses from the individual nodes involved in this request.
total: Option<i32>The total number of nodes responding.