pub struct NodePartitionsNode {
pub count: Option<i32>,
pub error: Option<String>,
pub id: Option<i32>,
pub lnn: Option<i32>,
pub partitions: Option<Vec<NodePartitionsNodePartition>>,
pub status: Option<i32>,
}Fields
count: Option<i32>Count of how many partitions are included.
error: Option<String>Error message, if the HTTP status returned from this node was not 200.
id: Option<i32>Node ID of the node reporting this information.
lnn: Option<i32>Logical node number of the node reporting this information.
partitions: Option<Vec<NodePartitionsNodePartition>>Partition information.
status: Option<i32>Status of the HTTP response from this node if not 200. If 200, this field does not appear.