pub struct NodeSensorsNode {
pub error: Option<String>,
pub id: Option<i32>,
pub lnn: Option<i32>,
pub sensors: Option<Vec<NodeSensorsNodeSensor>>,
pub status: Option<i32>,
}Fields
error: Option<String>Error message, if the HTTP status returned from this node was not 200.
id: Option<i32>Node ID of the node reporting this information.
lnn: Option<i32>Logical node number of the node reporting this information.
sensors: Option<Vec<NodeSensorsNodeSensor>>This node’s sensor information.
status: Option<i32>Status of the HTTP response from this node if not 200. If 200, this field does not appear.