pub struct NodeStateSmartfailNode {
pub dead: Option<bool>,
pub down: Option<bool>,
pub error: Option<String>,
pub id: Option<i32>,
pub in_cluster: Option<bool>,
pub lnn: Option<i32>,
pub readonly: Option<bool>,
pub shutdown_readonly: Option<bool>,
pub smartfailed: Option<bool>,
pub status: Option<i32>,
}Fields
dead: Option<bool>This node is dead (dead_devs).
down: Option<bool>This node is down (down_devs).
error: Option<String>Error message, if the HTTP status returned from this node was not 200.
id: Option<i32>Node ID of the node reporting this information.
in_cluster: Option<bool>This node is in the cluster (all_devs).
lnn: Option<i32>Logical node number of the node reporting this information.
readonly: Option<bool>This node is readonly (ro_devs).
shutdown_readonly: Option<bool>This node is shutdown readonly (down_devs).
smartfailed: Option<bool>This node is smartfailed (soft_devs).
status: Option<i32>Status of the HTTP response from this node if not 200. If 200, this field does not appear.