pub struct ProvidersAdsIdParams {Show 38 fields
pub allocate_gids: Option<bool>,
pub allocate_uids: Option<bool>,
pub assume_default_domain: Option<bool>,
pub authentication: Option<bool>,
pub check_online_interval: Option<i32>,
pub controller_time: Option<i32>,
pub create_home_directory: Option<bool>,
pub domain_controller: Option<String>,
pub domain_offline_alerts: Option<bool>,
pub findable_groups: Option<Vec<String>>,
pub findable_users: Option<Vec<String>>,
pub home_directory_template: Option<String>,
pub ignore_all_trusts: Option<bool>,
pub ignored_trusted_domains: Option<Vec<String>>,
pub include_trusted_domains: Option<Vec<String>>,
pub instance: Option<String>,
pub ldap_sign_and_seal: Option<bool>,
pub login_shell: Option<String>,
pub lookup_domains: Option<Vec<String>>,
pub lookup_groups: Option<bool>,
pub lookup_normalize_groups: Option<bool>,
pub lookup_normalize_users: Option<bool>,
pub lookup_users: Option<bool>,
pub machine_name: Option<String>,
pub machine_password_changes: Option<bool>,
pub machine_password_lifespan: Option<i32>,
pub node_dc_affinity: Option<String>,
pub node_dc_affinity_timeout: Option<i32>,
pub nss_enumeration: Option<bool>,
pub password: Option<String>,
pub reset_schannel: Option<bool>,
pub restrict_findable: Option<bool>,
pub sfu_support: Option<String>,
pub spns: Option<Vec<String>>,
pub store_sfu_mappings: Option<bool>,
pub unfindable_groups: Option<Vec<String>>,
pub unfindable_users: Option<Vec<String>>,
pub user: Option<String>,
}Fields
allocate_gids: Option<bool>Allocates an ID for an unmapped Active Directory (ADS) group. ADS groups without GIDs can be proactively assigned a GID by the ID mapper. If the ID mapper option is disabled, GIDs are not proactively assigned, and when a primary group for a user does not include a GID, the system may allocate one.
allocate_uids: Option<bool>Allocates a user ID for an unmapped Active Directory (ADS) user. ADS users without UIDs can be proactively assigned a UID by the ID mapper. IF the ID mapper option is disabled, UIDs are not proactively assigned, and when an identify for a user does not include a UID, the system may allocate one.
assume_default_domain: Option<bool>Enables lookup of unqualified user names in the primary domain.
authentication: Option<bool>Enables authentication and identity management through the authentication provider.
check_online_interval: Option<i32>Specifies the time in seconds between provider online checks.
controller_time: Option<i32>Specifies the current time for the domain controllers.
create_home_directory: Option<bool>Automatically creates a home directory on the first login.
domain_controller: Option<String>Specifies the domain controller to which the authentication service should send requests
domain_offline_alerts: Option<bool>Sends an alert if the domain goes offline.
findable_groups: Option<Vec<String>>Sets list of groups that can be resolved.
findable_users: Option<Vec<String>>Sets list of users that can be resolved.
home_directory_template: Option<String>Specifies the path to the home directory template.
ignore_all_trusts: Option<bool>If set to true, ignores all trusted domains.
ignored_trusted_domains: Option<Vec<String>>Includes trusted domains when ‘ignore_all_trusts’ is set to false.
include_trusted_domains: Option<Vec<String>>Includes trusted domains when ‘ignore_all_trusts’ is set to true.
instance: Option<String>Specifies Active Directory provider instance.
ldap_sign_and_seal: Option<bool>Enables encryption and signing on LDAP requests.
login_shell: Option<String>Specifies the login shell path.
lookup_domains: Option<Vec<String>>Limits user and group lookups to the specified domains.
lookup_groups: Option<bool>Looks up AD groups in other providers before allocating a group ID.
lookup_normalize_groups: Option<bool>Normalizes AD group names to lowercase before look up.
lookup_normalize_users: Option<bool>Normalize AD user names to lowercase before look up.
lookup_users: Option<bool>Looks up AD users in other providers before allocating a user ID.
machine_name: Option<String>Specifies name to join AD as.
machine_password_changes: Option<bool>Enables periodic changes of the machine password for security.
machine_password_lifespan: Option<i32>Sets maximum age of a password in seconds.
node_dc_affinity: Option<String>Specifies the domain controller for which the node has affinity.
node_dc_affinity_timeout: Option<i32>Specifies the timeout for the domain controller for which the local node has affinity.
nss_enumeration: Option<bool>Enables the Active Directory provider to respond to ‘getpwent’ and ‘getgrent’ requests.
password: Option<String>Specifies the password used during domain join.
reset_schannel: Option<bool>Resets the secure channel to the primary domain.
restrict_findable: Option<bool>Check the provider for filtered lists of findable and unfindable users and groups.
sfu_support: Option<String>Specifies whether to support RFC 2307 attributes on ADS domain controllers.
spns: Option<Vec<String>>Currently configured SPNs.
store_sfu_mappings: Option<bool>Stores SFU mappings permanently in the ID mapper.
unfindable_groups: Option<Vec<String>>Specifies groups that cannot be resolved by the provider.
unfindable_users: Option<Vec<String>>Specifies users that cannot be resolved by the provider.
user: Option<String>Specifies the user name that has permission to join a machine to the given domain.