pub struct ReportsThreatsReport {
pub file: Option<String>,
pub id: Option<String>,
pub policy_id: Option<String>,
pub remediation: Option<String>,
pub scan_id: Option<String>,
pub threat: Option<String>,
pub time: Option<i32>,
}Fields
file: Option<String>The file that contained the threat.
id: Option<String>A unique identifier for the report.
policy_id: Option<String>The id of the policy that found this threat.
remediation: Option<String>The action that was taken to remediate the threat.
scan_id: Option<String>The id of the scan report this threat is associated with.
threat: Option<String>A description of the threat that was found.
time: Option<i32>Trait Implementations
Sourceimpl Debug for ReportsThreatsReport
impl Debug for ReportsThreatsReport
Sourceimpl<'de> Deserialize<'de> for ReportsThreatsReport
impl<'de> Deserialize<'de> for ReportsThreatsReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more