SettingsGlobalGlobalSettings

Struct SettingsGlobalGlobalSettings 

pub struct SettingsGlobalGlobalSettings {
Show 26 fields pub alloc_retries: Option<i32>, pub gid_range_enabled: Option<bool>, pub gid_range_max: Option<i32>, pub gid_range_min: Option<i32>, pub gid_range_next: Option<i32>, pub group_uid: Option<i32>, pub load_providers: Option<Vec<String>>, pub min_mapped_rid: Option<i32>, pub null_gid: Option<i32>, pub null_uid: Option<i32>, pub on_disk_identity: Option<String>, pub rpc_block_time: Option<i32>, pub rpc_max_requests: Option<i32>, pub rpc_timeout: Option<i32>, pub send_ntlmv2: Option<bool>, pub space_replacement: Option<String>, pub system_gid_threshold: Option<i32>, pub system_uid_threshold: Option<i32>, pub uid_range_enabled: Option<bool>, pub uid_range_max: Option<i32>, pub uid_range_min: Option<i32>, pub uid_range_next: Option<i32>, pub unknown_gid: Option<i32>, pub unknown_uid: Option<i32>, pub user_object_cache_size: Option<i32>, pub workgroup: Option<String>,
}

Fields

alloc_retries: Option<i32>

Specifies the number of times to retry an ID allocation before failing.

gid_range_enabled: Option<bool>

If true, allocates GIDs from a fixed range.

gid_range_max: Option<i32>

Specifies the ending number for a fixed range from which GIDs are allocated.

gid_range_min: Option<i32>

Specifies the starting number for a fixed range from which GIDs are allocated.

gid_range_next: Option<i32>

Specifies the next GID to allocate.

group_uid: Option<i32>

Specifies the user iD for a group when requested by the kernel.

load_providers: Option<Vec<String>>

Specifies which providers are loaded by the authentication daemon (lsassd).

min_mapped_rid: Option<i32>

Starts the RID in the local domain to map a UID and a GID.

null_gid: Option<i32>

Specifies an alternative GID when the kernel is unable to retrieve a GID for a persona.

null_uid: Option<i32>

Specifies an alternative UID when the kernel is unable to retrieve a UID for a persona.

on_disk_identity: Option<String>

Specifies the type of identity that is stored on disk.

rpc_block_time: Option<i32>

Specifies the minimum amount of time in milliseconds to wait before performing an oprestart.

rpc_max_requests: Option<i32>

Specifies the maximum number of outstanding RPC requests.

rpc_timeout: Option<i32>

Specifies the maximum amount of time in seconds to wait for an idmap response.

send_ntlmv2: Option<bool>

If true, sends NTLMv2 responses.

space_replacement: Option<String>

Specifies the space replacement character.

system_gid_threshold: Option<i32>

Specifies the minimum GID to attempt to look up in the idmap database.

system_uid_threshold: Option<i32>

Specifies the minimum UID to attempt to look up in the idmap database.

uid_range_enabled: Option<bool>

If true, allocates UIDs from a fixed range.

uid_range_max: Option<i32>

Specifies the ending number for a fixed range from which UIDs are allocated.

uid_range_min: Option<i32>

Specifies the starting number for a fixed range from which UIDs are allocated.

uid_range_next: Option<i32>

Specifies the next UID to allocate.

unknown_gid: Option<i32>

Specifies the GID for the unknown (anonymous) group.

unknown_uid: Option<i32>

Specifies the UID for the unknown (anonymous) user.

user_object_cache_size: Option<i32>

Specifies the maximum size (in bytes) of the security object cache in the authentication daemon.

workgroup: Option<String>

Specifies the NetBIOS workgroup or domain.