SmbSettingsShareSettings

Struct SmbSettingsShareSettings 

pub struct SmbSettingsShareSettings {
Show 28 fields pub access_based_enumeration: Option<bool>, pub access_based_enumeration_root_only: Option<bool>, pub allow_delete_readonly: Option<bool>, pub allow_execute_always: Option<bool>, pub ca_timeout: Option<i32>, pub ca_write_integrity: Option<String>, pub change_notify: Option<String>, pub create_permissions: Option<String>, pub csc_policy: Option<String>, pub directory_create_mask: Option<i32>, pub directory_create_mode: Option<i32>, pub file_create_mask: Option<i32>, pub file_create_mode: Option<i32>, pub file_filter_extensions: Option<Vec<String>>, pub file_filter_type: Option<String>, pub file_filtering_enabled: Option<bool>, pub hide_dot_files: Option<bool>, pub host_acl: Option<Vec<String>>, pub impersonate_guest: Option<String>, pub impersonate_user: Option<String>, pub mangle_byte_start: Option<i32>, pub mangle_map: Option<Vec<String>>, pub ntfs_acl_support: Option<bool>, pub oplocks: Option<bool>, pub strict_ca_lockout: Option<bool>, pub strict_flush: Option<bool>, pub strict_locking: Option<bool>, pub zone: Option<String>,
}

Fields

access_based_enumeration: Option<bool>

Only enumerate files and folders the requesting user has access to.

access_based_enumeration_root_only: Option<bool>

Access-based enumeration on only the root directory of the share.

allow_delete_readonly: Option<bool>

Allow deletion of read-only files in the share.

allow_execute_always: Option<bool>

Allows users to execute files they have read rights for.

ca_timeout: Option<i32>

Persistent open timeout for the share.

ca_write_integrity: Option<String>

Specify the level of write-integrity on continuously available shares.

change_notify: Option<String>

Specify level of change notification alerts on the share.

create_permissions: Option<String>

Set the create permissions for new files and directories in share.

csc_policy: Option<String>

Client-side caching policy for the shares.

directory_create_mask: Option<i32>

Unix umask or mode bits.

directory_create_mode: Option<i32>

Unix umask or mode bits.

file_create_mask: Option<i32>

Unix umask or mode bits.

file_create_mode: Option<i32>

Unix umask or mode bits.

file_filter_extensions: Option<Vec<String>>

Specifies the list of file extensions.

file_filter_type: Option<String>

Specifies if filter list is for deny or allow. Default is deny.

file_filtering_enabled: Option<bool>

Enables file filtering on the share.

hide_dot_files: Option<bool>

Hide files and directories that begin with a period ‘.’.

host_acl: Option<Vec<String>>

An ACL expressing which hosts are allowed access. A deny clause must be the final entry.

impersonate_guest: Option<String>

Specify the condition in which user access is done as the guest account.

impersonate_user: Option<String>

User account to be used as guest account.

mangle_byte_start: Option<i32>

Specifies the wchar_t starting point for automatic byte mangling.

mangle_map: Option<Vec<String>>

Character mangle map.

ntfs_acl_support: Option<bool>

Support NTFS ACLs on files and directories.

oplocks: Option<bool>

Allow oplock requests.

strict_ca_lockout: Option<bool>

Specifies if persistent opens would do strict lockout on the share.

strict_flush: Option<bool>

Handle SMB flush operations.

strict_locking: Option<bool>

Specifies whether byte range locks contend against SMB I/O.

zone: Option<String>

Name of the access zone in which to update settings