pub struct SnapshotSnapshotsExtended {
pub snapshots: Option<Vec<SnapshotSnapshotExtended>>,
pub resume: Option<String>,
pub total: Option<i32>,
}Fields
snapshots: Option<Vec<SnapshotSnapshotExtended>>resume: Option<String>Continue returning results from previous call using this token (token should come from the previous call, resume cannot be used with other options).
total: Option<i32>Total number of items available.