pub struct StoragepoolStatusUnhealthyItemDiskpool {
pub drives: Vec<StoragepoolStatusUnprovisionedItem>,
pub id: i32,
pub name: String,
pub nodepool_id: Option<i32>,
pub protection_policy: String,
pub ssd_drives: Vec<StoragepoolStatusUnprovisionedItem>,
}Fields
drives: Vec<StoragepoolStatusUnprovisionedItem>The drives that are part of this disk pool.
id: i32The system ID given to the disk pool.
name: StringThe disk pool name.
nodepool_id: Option<i32>The system ID of the disk pool’s node pool, if it is in a node pool.
protection_policy: StringThe protection policy for the disk pool.
ssd_drives: Vec<StoragepoolStatusUnprovisionedItem>The SSDs that are part of this disk pool.