pub struct SyncRuleExtended {
pub description: String,
pub enabled: bool,
pub limit: i32,
pub schedule: Option<SyncRuleSchedule>,
pub id: String,
pub _type: String,
}Fields
description: StringUser-entered description of this performance rule.
enabled: boolWhether this performance rule is currently in effect during its specified intervals.
limit: i32Amount the specified system resource type is limited by this rule. Units are kb/s for bandwidth, files/s for file-count, processing percentage used for cpu, or percentage of maximum available workers.
schedule: Option<SyncRuleSchedule>A schedule defining when during a week this performance rule is in effect. If unspecified or null, the schedule will always be in effect.
id: StringThe system ID given to this performance rule.
_type: StringThe type of system resource this rule limits.