pub struct SyncRulesExtended {
pub resume: Option<String>,
pub rules: Vec<SyncRuleExtendedExtended>,
pub total: i32,
}Fields
resume: Option<String>Continue returning results from previous call using this token (token should come from the previous call, resume cannot be used with other options).
rules: Vec<SyncRuleExtendedExtended>total: i32Total number of items available.