pub struct WormSettingsExtended {
pub cdate: Option<Empty>,
}Fields
cdate: Option<Empty>To set the compliance clock to the current system time, PUT to this resource with an empty JSON object {} for the cdate value. This cluster must be in compliance mode to set the compliance clock.